/*==================================================================
 Program: CPS_Extract
 Purpose: Extracting CPS Voter Supplement data
===================================================================*/

** INSTRUCTIONS FOR DOWNLOADING DATASET:
* Go to https://cps.ipums.org/cps-action/variables/group. (You may have to create a free account.)
* Click 'SELECT SAMPLES'. 
* Deselect all pre-checked options. 
* Click 'SUPPLEMENT TOPICS' and then 'VOTER'.
* Select '2014' and '2010'.
* Click 'SUBMIT SAMPLE SELECTIONS'. 
* Under 'HOUSEHOLD'-->'CORE'-->'ECONOMIC CHARACTERISTICS', select 'FAMINC'.
* Under 'HOUSEHOLD' --> 'CORE' --> 'ECONOMIC CHARACTERISTICS', select 'STATEFIP'.
* Under 'PERSON' --> 'CORE' --> 'DEMOGRAPHICS', select 'AGE', 'SEX', 'RACE'.
* Under 'PERSON' --> 'CORE' --> 'ETHNICITY/NATIVITY', select 'HISPAN'.
* Under 'PERSON' --> 'CORE' --> 'EDUCATION', select 'EDUC'.
* Under 'PERSON' --> 'VOTER SUPPLEMENT', select all possible variables.
* Click 'CREATE DATA EXTRACT'.
* Change data format to desired format. (I used '.csv'.)
* Click 'ADD QUALITY FLAGS' and then add all quality flags.
* Click 'SUBMIT EXTRACT'.
* Wait ~2-3 minutes for the extract to process, and then download the file.

* Import dataset into Stata.

insheet using "$DataPath/CPS/cps_00012.csv", clear

* To format identifying and weighting variables with decimals, run
format hwtfinl   %10.4f
format cpsid     %14.0g
format wtfinl    %14.4f
format cpsidp    %14.0g
format vosuppwt  %10.4f

* To add appropriate labels to the variables, run
label var year      `"Survey year"'
label var serial    `"Household serial number"'
label var month     `"Month"'
label var hwtfinl   `"Household weight, Basic Monthly"'
label var cpsid     `"CPSID, household record"'
label var statefip  `"State (FIPS code)"'
label var faminc    `"Family income of householder"'
label var qfaminc   `"Data quality flag for FAMINC"'
label var pernum    `"Person number in sample unit"'
label var wtfinl    `"Final Basic Weight"'
label var cpsidp    `"CPSID, person record"'
label var age       `"Age"'
label var sex       `"Sex"'
label var race      `"Race"'
label var qage      `"Data quality flag for AGE"'
label var qsex      `"Data quality flag for SEX"'
label var qrace     `"Data quality flag for RACE"'
label var hispan    `"Hispanic origin"'
label var qhispan   `"Data quality flag for HISPAN"'
label var educ      `"Educational attainment recode"'
label var qeduc     `"Data quality flag for EDUC"'
label var vowhynot  `"Reason why eligible voter did not vote"'
label var voynotreg `"Reason why eligible voter did not register to vote"'
label var votehow   `"Method of voting in the most recent November election"'
label var votewhen  `"Voted on or before election day"'
label var voteres   `"Duration of residence at current address"'
label var voteresp  `"Self or proxy respondent for voter supplement"'
label var voted     `"Voted for the most recent November election"'
label var voreg     `"Registered for the most recent November election"'
label var vosuppwt  `"Voter Supplement Weight"'

label define month_lbl 01 `"January"'
label define month_lbl 02 `"February"', add
label define month_lbl 03 `"March"', add
label define month_lbl 04 `"April"', add
label define month_lbl 05 `"May"', add
label define month_lbl 06 `"June"', add
label define month_lbl 07 `"July"', add
label define month_lbl 08 `"August"', add
label define month_lbl 09 `"September"', add
label define month_lbl 10 `"October"', add
label define month_lbl 11 `"November"', add
label define month_lbl 12 `"December"', add
label values month month_lbl

label define statefip_lbl 01 `"Alabama"'
label define statefip_lbl 02 `"Alaska"', add
label define statefip_lbl 04 `"Arizona"', add
label define statefip_lbl 05 `"Arkansas"', add
label define statefip_lbl 06 `"California"', add
label define statefip_lbl 08 `"Colorado"', add
label define statefip_lbl 09 `"Connecticut"', add
label define statefip_lbl 10 `"Delaware"', add
label define statefip_lbl 11 `"District of Columbia"', add
label define statefip_lbl 12 `"Florida"', add
label define statefip_lbl 13 `"Georgia"', add
label define statefip_lbl 15 `"Hawaii"', add
label define statefip_lbl 16 `"Idaho"', add
label define statefip_lbl 17 `"Illinois"', add
label define statefip_lbl 18 `"Indiana"', add
label define statefip_lbl 19 `"Iowa"', add
label define statefip_lbl 20 `"Kansas"', add
label define statefip_lbl 21 `"Kentucky"', add
label define statefip_lbl 22 `"Louisiana"', add
label define statefip_lbl 23 `"Maine"', add
label define statefip_lbl 24 `"Maryland"', add
label define statefip_lbl 25 `"Massachusetts"', add
label define statefip_lbl 26 `"Michigan"', add
label define statefip_lbl 27 `"Minnesota"', add
label define statefip_lbl 28 `"Mississippi"', add
label define statefip_lbl 29 `"Missouri"', add
label define statefip_lbl 30 `"Montana"', add
label define statefip_lbl 31 `"Nebraska"', add
label define statefip_lbl 32 `"Nevada"', add
label define statefip_lbl 33 `"New Hampshire"', add
label define statefip_lbl 34 `"New Jersey"', add
label define statefip_lbl 35 `"New Mexico"', add
label define statefip_lbl 36 `"New York"', add
label define statefip_lbl 37 `"North Carolina"', add
label define statefip_lbl 38 `"North Dakota"', add
label define statefip_lbl 39 `"Ohio"', add
label define statefip_lbl 40 `"Oklahoma"', add
label define statefip_lbl 41 `"Oregon"', add
label define statefip_lbl 42 `"Pennsylvania"', add
label define statefip_lbl 44 `"Rhode Island"', add
label define statefip_lbl 45 `"South Carolina"', add
label define statefip_lbl 46 `"South Dakota"', add
label define statefip_lbl 47 `"Tennessee"', add
label define statefip_lbl 48 `"Texas"', add
label define statefip_lbl 49 `"Utah"', add
label define statefip_lbl 50 `"Vermont"', add
label define statefip_lbl 51 `"Virginia"', add
label define statefip_lbl 53 `"Washington"', add
label define statefip_lbl 54 `"West Virginia"', add
label define statefip_lbl 55 `"Wisconsin"', add
label define statefip_lbl 56 `"Wyoming"', add
label define statefip_lbl 61 `"Maine-New Hampshire-Vermont"', add
label define statefip_lbl 65 `"Montana-Idaho-Wyoming"', add
label define statefip_lbl 68 `"Alaska-Hawaii"', add
label define statefip_lbl 69 `"Nebraska-North Dakota-South Dakota"', add
label define statefip_lbl 70 `"Maine-Massachusetts-New Hampshire-Rhode Island-Vermont"', add
label define statefip_lbl 71 `"Michigan-Wisconsin"', add
label define statefip_lbl 72 `"Minnesota-Iowa"', add
label define statefip_lbl 73 `"Nebraska-North Dakota-South Dakota-Kansas"', add
label define statefip_lbl 74 `"Delaware-Virginia"', add
label define statefip_lbl 75 `"North Carolina-South Carolina"', add
label define statefip_lbl 76 `"Alabama-Mississippi"', add
label define statefip_lbl 77 `"Arkansas-Oklahoma"', add
label define statefip_lbl 78 `"Arizona-New Mexico-Colorado"', add
label define statefip_lbl 79 `"Idaho-Wyoming-Utah-Montana-Nevada"', add
label define statefip_lbl 80 `"Alaska-Washington-Hawaii"', add
label define statefip_lbl 81 `"New Hampshire-Maine-Vermont-Rhode Island"', add
label define statefip_lbl 83 `"South Carolina-Georgia"', add
label define statefip_lbl 84 `"Kentucky-Tennessee"', add
label define statefip_lbl 85 `"Arkansas-Louisiana-Oklahoma"', add
label define statefip_lbl 87 `"Iowa-N Dakota-S Dakota-Nebraska-Kansas-Minnesota-Missouri"', add
label define statefip_lbl 88 `"Washington-Oregon-Alaska-Hawaii"', add
label define statefip_lbl 89 `"Montana-Wyoming-Colorado-New Mexico-Utah-Nevada-Arizona"', add
label define statefip_lbl 90 `"Delaware-Maryland-Virginia-West Virginia"', add
label define statefip_lbl 99 `"State not identified"', add
label values statefip statefip_lbl

label define faminc_lbl 100 `"Under $5,000"'
label define faminc_lbl 110 `"Under $1,000"', add
label define faminc_lbl 111 `"Under $500"', add
label define faminc_lbl 112 `"$500 - 999"', add
label define faminc_lbl 120 `"$1,000 - 1,999"', add
label define faminc_lbl 121 `"$1,000 - 1,499"', add
label define faminc_lbl 122 `"$1,500-1,999"', add
label define faminc_lbl 130 `"$2,000 - 2,999"', add
label define faminc_lbl 131 `"$2,000 - 2,499"', add
label define faminc_lbl 132 `"$2,500 - 2,999"', add
label define faminc_lbl 140 `"$3,000 - 3,999"', add
label define faminc_lbl 141 `"$3,000 - 3,499"', add
label define faminc_lbl 142 `"$3,500 - 3,999"', add
label define faminc_lbl 150 `"$4,000 - 4,999"', add
label define faminc_lbl 200 `"$5,000 - 7,999"', add
label define faminc_lbl 210 `"$5,000 - 7,499"', add
label define faminc_lbl 220 `"$5,000 - 5,999"', add
label define faminc_lbl 230 `"$6,000 - 7,999"', add
label define faminc_lbl 231 `"$6,000 - 7,499"', add
label define faminc_lbl 232 `"$6,000 - 6,999"', add
label define faminc_lbl 233 `"$7,000 - 7,499"', add
label define faminc_lbl 234 `"$7,000 - 7,999"', add
label define faminc_lbl 300 `"$7,500 - 9,999"', add
label define faminc_lbl 310 `"$7,500 - 7,999"', add
label define faminc_lbl 320 `"$8,000 - 8,499"', add
label define faminc_lbl 330 `"$8,500 - 8,999"', add
label define faminc_lbl 340 `"$8,000 - 8,999"', add
label define faminc_lbl 350 `"$9,000 - 9,999"', add
label define faminc_lbl 400 `"$10,000 - 14,999"', add
label define faminc_lbl 410 `"$10,000 - 10,999"', add
label define faminc_lbl 420 `"$11,000 - 11,999"', add
label define faminc_lbl 430 `"$10,000 - 12,499"', add
label define faminc_lbl 440 `"$10,000 - 11,999"', add
label define faminc_lbl 450 `"$12,000 - 12,999"', add
label define faminc_lbl 460 `"$12,000 - 14,999"', add
label define faminc_lbl 470 `"$12,500 - 14,999"', add
label define faminc_lbl 480 `"$13,000 - 13,999"', add
label define faminc_lbl 490 `"$14,000 - 14,999"', add
label define faminc_lbl 500 `"$15,000 - 19,999"', add
label define faminc_lbl 510 `"$15,000 - 15,999"', add
label define faminc_lbl 520 `"$16,000 - 16,999"', add
label define faminc_lbl 530 `"$17,000 - 17,999"', add
label define faminc_lbl 540 `"$15,000 - 17,499"', add
label define faminc_lbl 550 `"$17,500 - 19,999"', add
label define faminc_lbl 560 `"$18,000 - 19,999"', add
label define faminc_lbl 600 `"$20,000 - 24,999"', add
label define faminc_lbl 700 `"$25,000 - 49,999"', add
label define faminc_lbl 710 `"$25,000 - 29,999"', add
label define faminc_lbl 720 `"$30,000 - 34,999"', add
label define faminc_lbl 730 `"$35,000 - 39,999"', add
label define faminc_lbl 740 `"$40,000 - 49,999"', add
label define faminc_lbl 800 `"$50,000 and over"', add
label define faminc_lbl 810 `"$50,000 - 74,999"', add
label define faminc_lbl 820 `"$50,000 - 59,999"', add
label define faminc_lbl 830 `"$60,000 - 74,999"', add
label define faminc_lbl 840 `"$75,000 and over"', add
label define faminc_lbl 841 `"$75,000 - 99,999"', add
label define faminc_lbl 842 `"$100,000 - 149,999"', add
label define faminc_lbl 843 `"$150,000 and over"', add
label define faminc_lbl 995 `"Missing"', add
label define faminc_lbl 996 `"Refused"', add
label define faminc_lbl 997 `"Don't know"', add
label define faminc_lbl 999 `"Blank"', add
label values faminc faminc_lbl

label define qfaminc_lbl 00 `"No change"'
label define qfaminc_lbl 04 `"Value to allocated value"', add
label define qfaminc_lbl 05 `"Blank to allocated value"', add
label define qfaminc_lbl 06 `"Don't know to allocated value"', add
label define qfaminc_lbl 07 `"Refused to allocated value"', add
label define qfaminc_lbl 08 `"Blank to longitudinal value"', add
label define qfaminc_lbl 09 `"Don't know to longitudinal value"', add
label define qfaminc_lbl 10 `"Refused to longitudinal value"', add
label values qfaminc qfaminc_lbl

label define age_lbl 00 `"Under 1 year"'
label define age_lbl 01 `"1"', add
label define age_lbl 02 `"2"', add
label define age_lbl 03 `"3"', add
label define age_lbl 04 `"4"', add
label define age_lbl 05 `"5"', add
label define age_lbl 06 `"6"', add
label define age_lbl 07 `"7"', add
label define age_lbl 08 `"8"', add
label define age_lbl 09 `"9"', add
label define age_lbl 10 `"10"', add
label define age_lbl 11 `"11"', add
label define age_lbl 12 `"12"', add
label define age_lbl 13 `"13"', add
label define age_lbl 14 `"14"', add
label define age_lbl 15 `"15"', add
label define age_lbl 16 `"16"', add
label define age_lbl 17 `"17"', add
label define age_lbl 18 `"18"', add
label define age_lbl 19 `"19"', add
label define age_lbl 20 `"20"', add
label define age_lbl 21 `"21"', add
label define age_lbl 22 `"22"', add
label define age_lbl 23 `"23"', add
label define age_lbl 24 `"24"', add
label define age_lbl 25 `"25"', add
label define age_lbl 26 `"26"', add
label define age_lbl 27 `"27"', add
label define age_lbl 28 `"28"', add
label define age_lbl 29 `"29"', add
label define age_lbl 30 `"30"', add
label define age_lbl 31 `"31"', add
label define age_lbl 32 `"32"', add
label define age_lbl 33 `"33"', add
label define age_lbl 34 `"34"', add
label define age_lbl 35 `"35"', add
label define age_lbl 36 `"36"', add
label define age_lbl 37 `"37"', add
label define age_lbl 38 `"38"', add
label define age_lbl 39 `"39"', add
label define age_lbl 40 `"40"', add
label define age_lbl 41 `"41"', add
label define age_lbl 42 `"42"', add
label define age_lbl 43 `"43"', add
label define age_lbl 44 `"44"', add
label define age_lbl 45 `"45"', add
label define age_lbl 46 `"46"', add
label define age_lbl 47 `"47"', add
label define age_lbl 48 `"48"', add
label define age_lbl 49 `"49"', add
label define age_lbl 50 `"50"', add
label define age_lbl 51 `"51"', add
label define age_lbl 52 `"52"', add
label define age_lbl 53 `"53"', add
label define age_lbl 54 `"54"', add
label define age_lbl 55 `"55"', add
label define age_lbl 56 `"56"', add
label define age_lbl 57 `"57"', add
label define age_lbl 58 `"58"', add
label define age_lbl 59 `"59"', add
label define age_lbl 60 `"60"', add
label define age_lbl 61 `"61"', add
label define age_lbl 62 `"62"', add
label define age_lbl 63 `"63"', add
label define age_lbl 64 `"64"', add
label define age_lbl 65 `"65"', add
label define age_lbl 66 `"66"', add
label define age_lbl 67 `"67"', add
label define age_lbl 68 `"68"', add
label define age_lbl 69 `"69"', add
label define age_lbl 70 `"70"', add
label define age_lbl 71 `"71"', add
label define age_lbl 72 `"72"', add
label define age_lbl 73 `"73"', add
label define age_lbl 74 `"74"', add
label define age_lbl 75 `"75"', add
label define age_lbl 76 `"76"', add
label define age_lbl 77 `"77"', add
label define age_lbl 78 `"78"', add
label define age_lbl 79 `"79"', add
label define age_lbl 80 `"80"', add
label define age_lbl 81 `"81"', add
label define age_lbl 82 `"82"', add
label define age_lbl 83 `"83"', add
label define age_lbl 84 `"84"', add
label define age_lbl 85 `"85"', add
label define age_lbl 86 `"86"', add
label define age_lbl 87 `"87"', add
label define age_lbl 88 `"88"', add
label define age_lbl 89 `"89"', add
label define age_lbl 90 `"90 (90+, 1988-2002)"', add
label define age_lbl 91 `"91"', add
label define age_lbl 92 `"92"', add
label define age_lbl 93 `"93"', add
label define age_lbl 94 `"94"', add
label define age_lbl 95 `"95"', add
label define age_lbl 96 `"96"', add
label define age_lbl 97 `"97"', add
label define age_lbl 98 `"98"', add
label define age_lbl 99 `"99+"', add
label values age age_lbl

label define sex_lbl 1 `"Male"'
label define sex_lbl 2 `"Female"', add
label define sex_lbl 9 `"NIU"', add
label values sex sex_lbl

label define race_lbl 100 `"White"'
label define race_lbl 200 `"Black/Negro"', add
label define race_lbl 300 `"American Indian/Aleut/Eskimo"', add
label define race_lbl 650 `"Asian or Pacific Islander"', add
label define race_lbl 651 `"Asian only"', add
label define race_lbl 652 `"Hawaiian/Pacific Islander only"', add
label define race_lbl 700 `"Other (single) race, n.e.c."', add
label define race_lbl 801 `"White-Black"', add
label define race_lbl 802 `"White-American Indian"', add
label define race_lbl 803 `"White-Asian"', add
label define race_lbl 804 `"White-Hawaiian/Pacific Islander"', add
label define race_lbl 805 `"Black-American Indian"', add
label define race_lbl 806 `"Black-Asian"', add
label define race_lbl 807 `"Black-Hawaiian/Pacific Islander"', add
label define race_lbl 808 `"American Indian-Asian"', add
label define race_lbl 809 `"Asian-Hawaiian/Pacific Islander"', add
label define race_lbl 810 `"White-Black-American Indian"', add
label define race_lbl 811 `"White-Black-Asian"', add
label define race_lbl 812 `"White-American Indian-Asian"', add
label define race_lbl 813 `"White-Asian-Hawaiian/Pacific Islander"', add
label define race_lbl 814 `"White-Black-American Indian-Asian"', add
label define race_lbl 815 `"American Indian-Hawaiian/Pacific Islander"', add
label define race_lbl 816 `"White-Black--Hawaiian/Pacific Islander"', add
label define race_lbl 817 `"White-American Indian-Hawaiian/Pacific Islander"', add
label define race_lbl 818 `"Black-American Indian-Asian"', add
label define race_lbl 819 `"White-American Indian-Asian-Hawaiian/Pacific Islander"', add
label define race_lbl 820 `"Two or three races, unspecified"', add
label define race_lbl 830 `"Four or five races, unspecified"', add
label define race_lbl 999 `"Blank"', add
label values race race_lbl

label define qage_lbl 00 `"No change"'
label define qage_lbl 01 `"Blank to value"', add
label define qage_lbl 02 `"Value to value"', add
label define qage_lbl 03 `"Allocated"', add
label define qage_lbl 04 `"Value to allocated value"', add
label define qage_lbl 05 `"Blank to allocated value"', add
label define qage_lbl 06 `"Don't know to allocated value"', add
label define qage_lbl 07 `"Refused to allocated value"', add
label define qage_lbl 08 `"Blank to longitudinal value"', add
label define qage_lbl 09 `"Don't know to longitudinal value"', add
label define qage_lbl 10 `"Refused to longitudinal value"', add
label values qage qage_lbl

label define qsex_lbl 00 `"No change"'
label define qsex_lbl 01 `"Blank to value"', add
label define qsex_lbl 02 `"Value to value"', add
label define qsex_lbl 03 `"Allocated"', add
label define qsex_lbl 04 `"Don't know to value"', add
label define qsex_lbl 05 `"Refused to value"', add
label define qsex_lbl 06 `"Blank to allocated value"', add
label define qsex_lbl 07 `"Don't know to allocated value"', add
label define qsex_lbl 08 `"Refused to allocated value"', add
label define qsex_lbl 09 `"Blank to longitudinal value"', add
label define qsex_lbl 10 `"Don't know to longitudinal value"', add
label define qsex_lbl 11 `"Refused to longitudinal value"', add
label define qsex_lbl 12 `"Allocated by IPUMS"', add
label values qsex qsex_lbl

label define qrace_lbl 00 `"No change / not allocated"'
label define qrace_lbl 04 `"Allocated-no method specified"', add
label define qrace_lbl 10 `"Value to value"', add
label define qrace_lbl 11 `"Blank to value"', add
label define qrace_lbl 12 `"Don't know to value"', add
label define qrace_lbl 13 `"Refused to value"', add
label define qrace_lbl 20 `"Value to longitudinal value"', add
label define qrace_lbl 21 `"Blank to longitudinal value"', add
label define qrace_lbl 22 `"Don't know to longitudinal value"', add
label define qrace_lbl 23 `"Refused to longitudinal value"', add
label define qrace_lbl 30 `"Value to allocated value long"', add
label define qrace_lbl 31 `"Blank to allocated value long"', add
label define qrace_lbl 32 `"Don't know to allocated value long"', add
label define qrace_lbl 33 `"Refused to allocated value long"', add
label define qrace_lbl 40 `"Value to allocated value"', add
label define qrace_lbl 41 `"Blank to allocated value"', add
label define qrace_lbl 42 `"Don't know to allocated value"', add
label define qrace_lbl 43 `"Refused to allocated value"', add
label define qrace_lbl 50 `"Value to blank"', add
label define qrace_lbl 52 `"Don't know to blank"', add
label define qrace_lbl 53 `"Refused to blank"', add
label values qrace qrace_lbl

label define hispan_lbl 000 `"Not Hispanic"'
label define hispan_lbl 100 `"Mexican"', add
label define hispan_lbl 102 `"Mexican American"', add
label define hispan_lbl 103 `"Mexicano/Mexicana"', add
label define hispan_lbl 104 `"Chicano/Chicana"', add
label define hispan_lbl 108 `"Mexican (Mexicano)"', add
label define hispan_lbl 109 `"Mexicano/Chicano"', add
label define hispan_lbl 200 `"Puerto Rican"', add
label define hispan_lbl 300 `"Cuban"', add
label define hispan_lbl 400 `"Dominican"', add
label define hispan_lbl 500 `"Salvadoran"', add
label define hispan_lbl 401 `"Other Hispanic"', add
label define hispan_lbl 410 `"Central/South American"', add
label define hispan_lbl 411 `"Central American, (excluding Salvadoran)"', add
label define hispan_lbl 412 `"South American"', add
label define hispan_lbl 901 `"Do not know"', add
label define hispan_lbl 902 `"N/A (and no response 1985-87)"', add
label values hispan hispan_lbl

label define qhispan_lbl 00 `"No change / not allocated"'
label define qhispan_lbl 01 `"Don't know-no change"', add
label define qhispan_lbl 02 `"Refused-no change"', add
label define qhispan_lbl 03 `"Value to value"', add
label define qhispan_lbl 04 `"Blank to value"', add
label define qhispan_lbl 05 `"Value to value - no error"', add
label define qhispan_lbl 06 `"Blank to N/A code"', add
label define qhispan_lbl 07 `"Don't know to value"', add
label define qhispan_lbl 08 `"Refused to value"', add
label define qhispan_lbl 09 `"Value to longitudinal value"', add
label define qhispan_lbl 10 `"Blank to longitudinal value"', add
label define qhispan_lbl 11 `"Don't know to longitudinal value"', add
label define qhispan_lbl 12 `"Refused to longitudinal value"', add
label define qhispan_lbl 13 `"Value to allocated value long"', add
label define qhispan_lbl 14 `"Blank to allocated value long"', add
label define qhispan_lbl 15 `"Don't know to allocated value long"', add
label define qhispan_lbl 16 `"Refused to allocated value long"', add
label define qhispan_lbl 17 `"Value to allocated value"', add
label define qhispan_lbl 18 `"Blank to allocated value"', add
label define qhispan_lbl 19 `"Don't know to allocated value"', add
label define qhispan_lbl 20 `"Refused to allocated value"', add
label define qhispan_lbl 21 `"Value to blank"', add
label values qhispan qhispan_lbl

label define educ_lbl 000 `"NIU or no schooling"'
label define educ_lbl 001 `"NIU or blank"', add
label define educ_lbl 002 `"None or preschool"', add
label define educ_lbl 010 `"Grades 1, 2, 3, or 4"', add
label define educ_lbl 011 `"Grade 1"', add
label define educ_lbl 012 `"Grade 2"', add
label define educ_lbl 013 `"Grade 3"', add
label define educ_lbl 014 `"Grade 4"', add
label define educ_lbl 020 `"Grades 5 or 6"', add
label define educ_lbl 021 `"Grade 5"', add
label define educ_lbl 022 `"Grade 6"', add
label define educ_lbl 030 `"Grades 7 or 8"', add
label define educ_lbl 031 `"Grade 7"', add
label define educ_lbl 032 `"Grade 8"', add
label define educ_lbl 040 `"Grade 9"', add
label define educ_lbl 050 `"Grade 10"', add
label define educ_lbl 060 `"Grade 11"', add
label define educ_lbl 070 `"Grade 12"', add
label define educ_lbl 071 `"12th grade, no diploma"', add
label define educ_lbl 072 `"12th grade, diploma unclear"', add
label define educ_lbl 073 `"High school diploma or equivalent"', add
label define educ_lbl 080 `"1 year of college"', add
label define educ_lbl 081 `"Some college but no degree"', add
label define educ_lbl 090 `"2 years of college"', add
label define educ_lbl 091 `"Associate's degree, occupational/vocational program"', add
label define educ_lbl 092 `"Associate's degree, academic program"', add
label define educ_lbl 100 `"3 years of college"', add
label define educ_lbl 110 `"4 years of college"', add
label define educ_lbl 111 `"Bachelor's degree"', add
label define educ_lbl 120 `"5+ years of college"', add
label define educ_lbl 121 `"5 years of college"', add
label define educ_lbl 122 `"6+ years of college"', add
label define educ_lbl 123 `"Master's degree"', add
label define educ_lbl 124 `"Professional school degree"', add
label define educ_lbl 125 `"Doctorate degree"', add
label define educ_lbl 999 `"Missing/Unknown"', add
label values educ educ_lbl

label define qeduc_lbl 00 `"No change"'
label define qeduc_lbl 01 `"Allocated"', add
label define qeduc_lbl 02 `"Value to blank"', add
label define qeduc_lbl 03 `"Blank to allocated value"', add
label define qeduc_lbl 04 `"Don't know to allocated value"', add
label define qeduc_lbl 05 `"Refused to allocated value"', add
label define qeduc_lbl 06 `"Blank to longitudinal value"', add
label define qeduc_lbl 07 `"Don't know to longitudinal value"', add
label define qeduc_lbl 08 `"Refused to longitudinal value"', add
label define qeduc_lbl 09 `"Don't know to blank"', add
label define qeduc_lbl 10 `"Refused to blank"', add
label values qeduc qeduc_lbl

label define vowhynot_lbl 01 `"Illness or disability (own or family's)"'
label define vowhynot_lbl 02 `"Out of town or away from home"', add
label define vowhynot_lbl 03 `"Forgot to vote (or send in absentee ballot)"', add
label define vowhynot_lbl 04 `"Not interested, felt my vote wouldn't make a difference"', add
label define vowhynot_lbl 05 `"Too busy, conflicting work or school schedule"', add
label define vowhynot_lbl 06 `"Transportation problems"', add
label define vowhynot_lbl 07 `"Didn't like candidates or campaign issues"', add
label define vowhynot_lbl 08 `"Registration problems (i.e., didn't receive absentee ballot, not registered in current location)"', add
label define vowhynot_lbl 09 `"Bad weather conditions"', add
label define vowhynot_lbl 10 `"Inconvenient polling place or hours or lines too long"', add
label define vowhynot_lbl 11 `"Other"', add
label define vowhynot_lbl 96 `"Refused"', add
label define vowhynot_lbl 97 `"Don't know"', add
label define vowhynot_lbl 98 `"No Response"', add
label define vowhynot_lbl 99 `"NIU"', add
label values vowhynot vowhynot_lbl

label define voynotreg_lbl 01 `"Did not meet registration deadlines"'
label define voynotreg_lbl 02 `"Did not know where or how to register"', add
label define voynotreg_lbl 03 `"Did not meet residency requirements/did not live here long enough"', add
label define voynotreg_lbl 04 `"Permanent illness or disability"', add
label define voynotreg_lbl 05 `"Difficulty with English"', add
label define voynotreg_lbl 06 `"Not interested in the election or not involved in politics"', add
label define voynotreg_lbl 07 `"My vote would not make a difference"', add
label define voynotreg_lbl 08 `"Not eligible to vote"', add
label define voynotreg_lbl 09 `"Other reason"', add
label define voynotreg_lbl 96 `"Refused"', add
label define voynotreg_lbl 97 `"Don't know"', add
label define voynotreg_lbl 98 `"No Response"', add
label define voynotreg_lbl 99 `"NIU"', add
label values voynotreg voynotreg_lbl

label define votehow_lbl 01 `"In person"'
label define votehow_lbl 02 `"By mail"', add
label define votehow_lbl 97 `"Don't know"', add
label define votehow_lbl 96 `"Refused"', add
label define votehow_lbl 98 `"No Response"', add
label define votehow_lbl 99 `"NIU"', add
label values votehow votehow_lbl

label define votewhen_lbl 01 `"On election day"'
label define votewhen_lbl 02 `"Before election day"', add
label define votewhen_lbl 96 `"Refused"', add
label define votewhen_lbl 97 `"Don't know"', add
label define votewhen_lbl 98 `"No Response"', add
label define votewhen_lbl 99 `"NIU"', add
label values votewhen votewhen_lbl

label define voteres_lbl 010 `"Less than 1 year"'
label define voteres_lbl 011 `"Less than 1 month"', add
label define voteres_lbl 012 `"1-6 months"', add
label define voteres_lbl 013 `"7-11 months"', add
label define voteres_lbl 020 `"1-2 years"', add
label define voteres_lbl 030 `"3 or more years"', add
label define voteres_lbl 031 `"3-4 years"', add
label define voteres_lbl 032 `"3-5 years"', add
label define voteres_lbl 033 `"5 years or longer"', add
label define voteres_lbl 034 `"6 years or longer"', add
label define voteres_lbl 035 `"6-9 years"', add
label define voteres_lbl 036 `"10 years or longer"', add
label define voteres_lbl 996 `"Refused"', add
label define voteres_lbl 997 `"Don't know"', add
label define voteres_lbl 998 `"No Response"', add
label define voteres_lbl 999 `"NIU"', add
label values voteres voteres_lbl

label define voteresp_lbl 01 `"Self"'
label define voteresp_lbl 02 `"Proxy"', add
label define voteresp_lbl 09 `"NIU"', add
label values voteresp voteresp_lbl

label define voted_lbl 01 `"Did not vote"'
label define voted_lbl 02 `"Voted"', add
label define voted_lbl 96 `"Refused"', add
label define voted_lbl 97 `"Don't know"', add
label define voted_lbl 98 `"No Response"', add
label define voted_lbl 99 `"Not in universe"', add
label values voted voted_lbl

label define voreg_lbl 01 `"Did not register"'
label define voreg_lbl 02 `"Registered"', add
label define voreg_lbl 96 `"Refused"', add
label define voreg_lbl 97 `"Don't know"', add
label define voreg_lbl 98 `"Not reported / Not available"', add
label define voreg_lbl 99 `"Not in universe"', add
label values voreg voreg_lbl

*cf _all using "$Temp/CPS_raw.dta"
save "$Temp/CPS_raw.dta", replace
