/*=======================================================================
 Program: Master_Piv.do
 Purpose: Master Directory File for "One in a Million"
=======================================================================*/

clear all

/*================================================
SPECIFY MAIN PATH
================================================*/
global Main = ""

* Paths for outputting objects (figures or tables).
global ObPath = "$Main/Ob"

* Paths for location of data.
global DataPath = "$Main/Data"

* Paths for analysis files.
global Temp = "$Main/Temp"
global Main_P = "$Main/Code"

/*================================================
Create date-time to append to the names of tables.
Date global will be "Year_Month_Day".
================================================*/
global date = ""
qui do "$Main_P/GlobalsTime.do"

/*================================================
Specs:
global spec = "$time"
global spec = "ThetaOne_$time"
global spec = "ThetaHalf_$time"
global spec = "Theta20Perc_$time"
=================================================*/
global spec = "$time"

* Save data to the temp file for usage.
foreach yX in 2010 2014{
	use "$DataPath/`yX'_RCT.dta", clear
	save "$Temp/`yX'_RCT.dta", replace
}


/*=======================================================================
2010 RCT MAIN RESULTS
=======================================================================*/
do "$Main_P/2010/Main_e2010.do"

/*=======================================================================
2014 RCT MAIN RESULTS
=======================================================================*/
do "$Main_P/2014/Main_e2014.do"

/*=======================================================================
ANALYSIS COMBINING THE 2010 AND 2014 RCTS
This produces Table 7 and Table 8 in main text.
It needs to be run twice to create Tables 7-8: 
(1) Using theta=1.
(2) Using theta=0.5.

For Appendix Table C30, use theta=0.2 for columns 5-8.
For Appendix Table C33, use theta=1 and look at "Overall_2Measures" 
calculations.
=======================================================================*/
do "$Main_P/Combo/Combo_Tables.do"

/*=======================================================================
COMPARE RCT SAMPLE TO VOTER DATA IN CPS
=======================================================================*/
* Extract CPS data 
do "$Main_P/CPS/CPS_Extract.do"

* Clean the data
qui do "$Main_P/CPS/CPS_Clean.do"

* Make table.
do "$Main_P/CPS/CPS_Table.do"


/*=======================================================================
HISTORICAL DATA ON CLOSE ELECTIONS
Purpose: Report instances of elections decided by 100 votes or fewer
or by 1,000 votes or fewer.
=======================================================================*/

* Clean historical data.
do "$Main_P/Historical/Clean_Hist.do"

* Do counts with historical data.
do "$Main_P/Historical/Main_Hist.do"





